@@ -89,8 +89,8 @@ sub query {
 }
 
 sub tables {
-  [grep { $_ !~ /^(?:pg_catalog|information_schema)\./ }
-      shift->dbh->tables('', '', '', '')];
+  my @tables = shift->dbh->tables('', '', '', '');
+  return [grep { $_ !~ /^(?:pg_catalog|information_schema)\./ } @tables];
 }
 
 sub unlisten {
@@ -202,6 +202,9 @@ L<Mojo::Pg::Database> implements the following attributes.
 
 L<DBD::Pg> database handle used for all queries.
 
+  # Use DBI utility methods
+  my $quoted = $db->dbh->quote_identifier('foo.bar');
+
 =head2 pg
 
   my $pg = $db->pg;
@@ -235,7 +238,7 @@ L<Mojo::Pg::Transaction/"commit"> has been called before it is destroyed.
 
   $db->disconnect;
 
-Disconnect L</"dbh"> and prevent it from getting cached again.
+Disconnect L</"dbh"> and prevent it from getting reused.
 
 =head2 dollar_only
 
@@ -290,7 +293,7 @@ Execute a blocking L<SQL|http://www.postgresql.org/docs/current/static/sql.html>
 statement and return a L<Mojo::Pg::Results> object with the results. The
 L<DBD::Pg> statement handle will be automatically reused when it is not active
 anymore, to increase the performance of future queries. You can also append a
-callback to perform operation non-blocking.
+callback to perform operations non-blocking.
 
   $db->query('insert into foo values (?, ?, ?)' => @values => sub {
     my ($db, $err, $results) = @_;
@@ -298,6 +301,15 @@ callback to perform operation non-blocking.
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
 
+Hash reference arguments containing a value named C<json>, will be encoded to
+JSON text with L<Mojo::JSON/"to_json">. To accomplish the reverse, you can use
+the method L<Mojo::Pg::Results/"expand">, which automatically decodes all fields
+of the types C<json> and C<jsonb> with L<Mojo::JSON/"from_json"> to Perl values.
+
+  # "I ♥ Mojolicious!"
+  $db->query('select ?::jsonb as foo', {json => {bar => 'I ♥ Mojolicious!'}})
+    ->expand->hash->{foo}{bar};
+
 =head2 tables
 
   my $tables = $db->tables;
